"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const path = require("path");
const _glob = require("glob");
exports.assertPathExists = (dir) => {
    if (!fs.existsSync(dir)) {
        throw Error(`path does not exist: ${dir}`);
    }
};
exports.isDirectory = source => {
    return fs.lstatSync(source).isDirectory();
};
exports.glob = (pattern) => {
    return _glob.sync(pattern);
};
function isObject(o) {
    return typeof o === "object" && !(o instanceof Array);
}
exports.isObject = isObject;
function isArray(o) {
    return typeof o === "object" && o instanceof Array;
}
exports.isArray = isArray;
function flatten(ls) {
    const result = [];
    for (let i = 0, il = ls.length; i < il; i++) {
        result.push(...ls[i]);
    }
    return result;
}
exports.flatten = flatten;
function hashCode(str) {
    return str.split("").reduce((prevHash, currVal) => ((prevHash << 5) - prevHash + currVal.charCodeAt(0)) | 0, 0);
}
exports.hashCode = hashCode;
function copyResourceFiles(container, map) {
    return new Promise(resolve => {
        let scheduled = 0;
        function maybeDone() {
            if (scheduled === 0) {
                resolve();
            }
        }
        for (const key in map) {
            const source = path.join(__dirname, key);
            const target = path.join(container, map[key]);
            let statSource;
            try {
                statSource = fs.statSync(source);
            }
            catch (e) {
                console.error("unable to find resource file:", key);
                continue;
            }
            try {
                const statTarget = fs.statSync(target);
                if (+statSource.mtime === +statTarget.mtime && statSource.size === statTarget.size) {
                    continue;
                }
            }
            catch (_a) { }
            scheduled += 1;
            fs.copy(source, target, { preserveTimestamps: true }, err => {
                if (err)
                    console.error(err);
                scheduled -= 1;
                maybeDone();
            });
        }
        maybeDone();
    });
}
exports.copyResourceFiles = copyResourceFiles;
