"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const child_process_1 = require("child_process");
const server_1 = require("./server");
const nodePath = process.execPath;
const yarnPath = path.join(__dirname, "../node_modules/yarn/lib/cli.js");
function log(result) {
    console.log(result.output);
    console.error(result.error);
    server_1.Server.logError(result.error);
    return result;
}
const run = (args, callback) => {
    return new Promise((resolve, reject) => {
        args.unshift(yarnPath);
        let outputBuffers = [];
        let errorBuffers = [];
        const childProcess = child_process_1.spawn(nodePath, args, { cwd: process.cwd() });
        childProcess.stdout.on("data", (data) => {
            outputBuffers.push(data);
        });
        childProcess.stderr.on("data", (data) => {
            errorBuffers.push(data);
        });
        const result = () => {
            return { output: Buffer.concat(outputBuffers).toString(), error: Buffer.concat(errorBuffers).toString() };
        };
        childProcess.on("error", () => reject(log(result())));
        childProcess.on("close", () => setTimeout(() => resolve(log(result())), 100));
    }).then(result => {
        if (callback) {
            callback();
        }
        return result;
    });
};
exports.install = args => {
    return run(["install", ...args]);
};
exports.add = args => {
    return run(["add", ...args]);
};
exports.remove = args => {
    return run(["remove", ...args]);
};
exports.publish = args => {
    return run(["publish", ...args]);
};
exports.outdated = args => {
    return run(["outdated", ...args]);
};
exports.list = args => {
    return run(["config", "list", ...args]);
};
exports.upgrade = args => {
    return run(["upgrade", ...args]);
};
exports.check = args => {
    return run(["check", ...args]);
};
